@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-# copyright 2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
-# copyright 2013 CEA (Saclay, FRANCE), all rights reserved.
+# copyright 2014 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2014 CEA (Saclay, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -16,7 +16,5 @@
 # You should have received a copy of the GNU Lesser General Public License along
 # with this program. If not, see <http://www.gnu.org/licenses/>.
 
-add_cube('file')
-add_relation_definition('GenomicMeasure', 'results_file', 'File')
-add_entity_type('CghResult')
-add_entity_type('Mutation')
+
+sync_schema_props_perms(('Snp', 'gene', 'Gene'))
